@@ -42,27 +42,33 @@
 #' coef(mod)
 #' logLik(mod)
 #' @export
-plfit <- function (y, x = NULL, ref = 1, start = NULL, weights = NULL,
+plfit <- function (y, x = NULL, ref = 1L, start = NULL, weights = NULL,
                    offset = NULL, ..., estfun = FALSE, object = FALSE) {
     x <- !(is.null(x) || NCOL(x) == 0L)
     offset <- !is.null(offset)
     if (x || offset)
         warning("unused argument(s): ",
                 paste(c("x"[x], "offset"[offset]), collapse = ","))
-    res <- PlackettLuce(y, start = start, weights = weights, ...)
-    if (object) {
-        # returning in order to compute final vcov etc, so can aggregate now
-        uniq <- !duplicated(attr(y, "id"))
-        g <- match(attr(y, "id"), attr(y, "id")[uniq])
-        res$rankings <- structure(res$rankings[uniq,],
-                                 class = "rankings")
-        res$weights <- tapply(res$weights, g, sum)
+    dots <- list(...)
+    if ("adherence" %in% names(dots) & !"gamma" %in% names(dots)){
+        stop("adherence can not be fixed in a Plackett-Luce tree")
     }
+    res <- PlackettLuce(y, start = start, weights = weights, ...)
     if (estfun) {
         percomp <- estfun.PlackettLuce(res, ref = ref)
-        if (object) percomp <- percomp[g, , drop = FALSE]
         estfun <- rowsum(as.matrix(percomp), attr(y, "index"))
     } else estfun <- NULL
+    if (object) {
+        # returning in order to compute final vcov etc, so can
+        # aggregate equal rankings now, across rankers
+        if (is.null(res$gamma)) {
+            uniq <- !duplicated(attr(y, "id"))
+            g <- match(attr(y, "id"), attr(y, "id")[uniq])
+            res$rankings <- structure(res$rankings[uniq,],
+                                      class = "rankings")
+            res$weights <- c(tapply(res$weights, g, sum))
+        }
+    }
     list(coefficients = coef(res, ref = ref),
          maxTied = res$maxTied,
          objfun = -res$loglik,
@@ -70,65 +76,82 @@ plfit <- function (y, x = NULL, ref = 1, start = NULL, weights = NULL,
          object = if (object) res else NULL)
 }
 
-# log-likelihood derivatives (score function)
+# log-likelihood derivatives (score function) per ranking
 #' @method estfun PlackettLuce
 #' @importFrom sandwich estfun
 #' @export
-estfun.PlackettLuce <- function(x, ref = 1, ...) {
+estfun.PlackettLuce <- function(x, ref = 1L, ...) {
     D <- x$maxTied
     # get coefficients (unconstrained)
     coef <- x$coefficients
-    N <- length(coef) - D + 1
-    alpha <- coef[1:N]
-    delta <- c(1, coef[-c(1:N)])
-    # get choices and alternatives for each ranking
+    N <- length(coef) - D + 1L
+    alpha <- coef[1L:N]
+    delta <- c(1.0, coef[-c(1L:N)])
+    # get free choices and alternatives for each ranking
     choices <- choices(x$rankings, names = FALSE)
-    # derivative wrt to alpha part 1: 1/(size of selected set)
+    free <- lengths(choices$alternatives) != 1L
+    choices <- lapply(choices, `[`,  free)
+    # derivative wrt to log alpha part 1: 1/(size of selected set)
     nr <- nrow(x$rankings)
-    A <- matrix(0, nrow = nr, ncol = N,
+    A <- matrix(0.0, nrow = nr, ncol = N,
                 dimnames = list(NULL, names(alpha)))
     choices$choices <- split(choices$choices, choices$ranking)
     for (i in seq_len(nr)){
         r <- choices$choices[[i]]
         len <- lengths(r)
-        A[i, unlist(r)] <- rep(1/len, len)
+        if (!is.null(x$adherence)){
+            A[i, unlist(r)] <- rep(x$adherence[x$ranker[i]]/len, len)
+        } else A[i, unlist(r)] <- rep(1L/len, len)
     }
     # derivative wrt delta part 1: row TRUE where selected set has cardinality d
-    if (D > 1){
-        B <- matrix(nrow = nr, ncol = D - 1,
-                    dimnames = list(NULL, names(delta[-1])))
-        for (d in 2:D){
-            B[, d - 1] <- apply(A == 1/d, 1, any)
+    if (D > 1L){
+        B <- matrix(nrow = nr, ncol = D - 1L,
+                    dimnames = list(NULL, names(delta[-1L])))
+        for (d in 2L:D){
+            if (!is.null(x$adherence)) {
+                B[, d - 1L] <- apply(A == x$adherence[x$ranker]/d, 1L, any)
+            } else B[, d - 1L] <- apply(A == 1L/d, 1L, any)
         }
     }
     # derivatives part 2: expectation of alpha | delta per set to choose from
-    # id unique alternatives - need to see how weights would fit in
     size <- lengths(choices$alternatives)
     ord <- order(size)
-    unique_alternatives <- unique(choices$alternatives[ord])
+    if (!is.null(x$adherence)){
+        # don't group
+        a <- x$adherence[x$ranker][choices$ranking]
+        unique_alternatives <- choices$alternatives
+    } else {
+        a <- NULL
+        unique_alternatives <- unique(choices$alternatives[ord])
+    }
     na <- lengths(unique_alternatives)
-    R <- matrix(0, nrow = length(na), ncol = max(na))
+    R <- matrix(0L, nrow = length(na), ncol = max(na))
     R[cbind(rep(seq_along(unique_alternatives), na), sequence(na))] <-
         unlist(unique_alternatives)
     G <- seq_along(unique_alternatives)
     G <- lapply(seq_len(max(na)), function(i) G[na == i])
-    S <- setdiff(unique(na), 1)
+    P <- unique(na)
     res <- expectation(c("alpha", "delta"), alpha, delta,
-                       N = N, D = D, S = unique(na), R, G)
-    h <- match(choices$alternatives, unique_alternatives)
-    A <- A - rowsum(res$expA[h,], choices$ranking)
+                       a, N, D, P, R, G, W = NULL)
+
+    if (!is.null(x$adherence)){
+        h <- seq_len(nrow(R))
+    } else {
+        h <- match(choices$alternatives, unique_alternatives)
+    }
+    A <- (A - rowsum(res$expA[h,], choices$ranking)) * x$weights
     if (!is.null(ref) && ref %in% names(alpha)) {
         ref <- which(names(alpha) == ref)
     }
-    if (D == 1) {
+    if (D == 1L) {
         if (!is.null(ref)) {
             return(A[, -ref, drop = FALSE])
         } else return(A)
     }
     # N.B. expectation of delta should include delta*, but cancelled out in
     # in iterative scaling so omitted!
-    res$expB <- sweep(res$expB, 2, delta[-1], "*")
-    B <- B - rowsum(res$expB[h,], choices$ranking)
+    res$expB <- sweep(res$expB, 2L, delta[-1L], "*")
+    B <- (B - rowsum(res$expB[h,], choices$ranking)) * x$weights
     if (!is.null(ref)) {
         return(cbind(A[, -ref, drop = FALSE], B))
     } else return(cbind(A[, drop = FALSE], B))
